OC.L10N.register(
    "activity",
    {
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 來複製",
    "{name} (invisible)" : "{name} （隱藏）",
    "{name} (restricted)" : "{name} （受限）",
    "Home" : "首頁",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "這裡將顯示檔案的新增、更動、分享等動態",
    "There are no events for this filter" : "在此篩選器下沒有活動",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Open {filename}" : "開啟 {filename}",
    "Personal activity feed for %s" : "%s 的個人動態摘要",
    "Your feed URL is invalid" : "您的 Feed URL 是無效的",
    "Your settings have been updated." : "您的設定已更新。",
    "Settings have been updated." : "設定已更新。",
    "Recent activity" : "近期活動",
    "Daily activity summary for %s" : "%s 的每日活動摘要",
    "_and %n more _::_and %n more _" : ["以及其餘 %n 項"],
    "All activities" : "所有活動",
    "By others" : "由其他人",
    "By you" : "由您",
    "Activity at %s" : "%s 上的活動",
    "Hello %s" : "%s你好",
    "Hello %s," : "哈囉 %s ，",
    "There was some activity at %s" : "%s 有一些活動",
    "Mail" : "電子郵件",
    "Push" : "推送",
    "Activity" : "活動",
    "Notifications" : "通知",
    "This application enables users to view a log of activities about them or about files." : "本應用程式可以讓使用者檢視有關自己或檔案的活動記錄。",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "此應用程式讓使用者能夠在 Nextcloud 中查看與其檔案相關的操作。\n\t\t啟用後，使用者將在其選單中看到一個「活動」新圖示。\n\t\t點選後，將顯示一個新頁面，以供使用者追蹤與文件相關的活動 ─ 包含新增檔案、已刪除檔案、移動、重新命名、更新和分享活動。\n\t\t使用者可以在其個人選單中配置其各自的活動設定。\n\t\t此設定了想要記錄的活動類型，以及使用者是否可看到自己的活動，\n\t\t並是否僅為線上提供，以及是否定期收到電子郵件摘要。\n\t\t活動說明文件中提供了更多訊息。",
    "Activity notification configuration" : "活動通知設定",
    "Send email" : "傳送電子郵件",
    "Send push notification" : "傳送推播通知",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電子郵件，才能接收通知。",
    "Send activity emails" : "寄送有關活動的郵件",
    "As soon as possible" : "盡快",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每週",
    "No activity yet" : "尚無活動",
    "Unable to load the activity list" : "無法載入活動清單",
    "Notification" : "通知",
    "Enable notification emails" : "啟用電子郵件通知",
    "Choose for which activities you want to get an email or push notification." : "選擇哪些活動是您要透過電子郵件或推送所接收的通知。",
    "Choose for which activities you want to get a push notification." : "選擇你要推送哪些活動的通知。",
    "Daily activity summary" : "每日事件摘要",
    "Send daily activity summary in the morning" : "於早上傳送每日活動摘要",
    "Activities" : "活動",
    "No activities" : "無活動",
    "Default settings" : "預設設定",
    "Configure the default notification settings for new users." : "為新使用者設定預設的通知設定。",
    "Unable to save the settings" : "無法儲存設定",
    "Activity feed" : "活動摘要",
    "Activity settings" : "活動設定",
    "Enable RSS feed" : "啟用 RSS 摘要",
    "RSS feed" : "RSS 摘要",
    "Personal notification settings" : "個人通知設定",
    "No more events to load" : "已載入所有事件",
    "Activity notification for %s" : "%s 的活動通知",
    "Configure the default notification settings." : "設定預設的通知設定。",
    "Send notification emails:" : "透過電子郵件接收通知",
    "Settings" : "設定",
    "Personal Activity Settings" : "個人活動設定",
    "activities" : "活動",
    "Send activity emails:" : "傳送事件電子郵件："
},
"nplurals=1; plural=0;");
